jjowl - opinied python module for processing OWL ontologies

# Synopsis

    owlcat  a.ttl b.owl c.ttl > all.ttl
    owlclass a.ttl     show class taxonomy
    owlgrep pattern a.ttl
    owllabel2term a.ttl > new.ttl    - new IRIRef from rfds:label
    owlexpand a.ttl  - expand and pretty print

    owlxdxf  a.ttl  -- Build a XDXF dictionary (seealso goldendict)

As a module:

    import jjowl
    ... FIXME

# Description


